      SUBROUTINE OULAN_EXTRACT
!-----------------------------------------------------------------------
!  SP OULAN_EXTRACT : extractions successives, par types de messages
!  ----------------
!  Auteur        : Ph. Caille                                    11/94
!  Modifications : F. Guillaume (10/2006)
!                :- changement dans les extractions par morceaux pour le
!                   type TOVSHIRS uniquement.
!                 - si longitude_W > longitude_E alors on passe par 180
!    12/06/2007 :F Guillaume : extraction PAOB pour Aladin Reunion
!    02/04/2008 :F Guillaume : rajout nom de base ODB cible,
!                              ecriture des BATORMAP ref. et reel
!                              renommage de OBSOUL en OBSOUL.xxxxxxxx
!    01/09/2014 :F Guillaume : ajout des types SYNOPA, SHIPA (extraction
!                              sur les anciennes tables SYNOP, SHIP.
!-----------------------------------------------------------------------
      IMPLICIT LOGICAL(L)
      PARAMETER ( JP_MAX_MES = 50   , JP_MAX_NB_SAT = 4  )

#include "oulan_pardimo.h"
#include "oulan_yomdirs.h"
#include "oulan_yomtomv.h"
#include "oulan_yomdate.h"
#include "oulan_yomnbob.h"
#include "oulan_yomcsts.h"

      CHARACTER   CLABORT*15,CLTYPM*10,CL_CODPRO*3,CLTYPGEN(13)*6
!FGFG
      CHARACTER   CLTYPM2*10
!FGFG
      CHARACTER   CLNOEC(JP_MAX_MES)*6,CLNBSAT(JP_MAX_NB_SAT)*8
      INTEGER     IPLEIN(JP_MAX_MES),INBSATEL(JP_MAX_NB_SAT)
      INTEGER     I_LISTE_SAT(JPNMXSTO),IG,IB200
      
      LOGICAL   :: LMERIDIAN
      REAL      :: ZLATBN,ZLATBS,ZLONBO,ZLONBE
      INTEGER   :: ITERLAT,ITERLON,IPASLAT,IPASLON
      INTEGER   :: JLAT,JLON,N_NB_BOITES,N_NB_BDL,ret

      INTEGER, DIMENSION(160,2) :: M_NO_BBDL
      REAL, DIMENSION(32932,4) :: A_LLBOX
      CHARACTER(LEN=15) :: FULL_NAME
      CHARACTER(LEN=17) :: FULL_BMAP

      CLABORT = 'OULAN_EXTRACT  '
      FULL_NAME = 'OBSOUL.'//CNAMEOBSOUL(1:8)
      FULL_BMAP = 'batormap.'//CNAMEOBSOUL(1:8)

      INBOBS        = 0
      INBSYNOP      = 0
      INBSYNOPA     = 0
      INBSHIP       = 0
      INBSYNOR      = 0
      INBRADOMEH    = 0
      INBAIREP      = 0
      INBAMDAR      = 0
      INBACAR       = 0
      INBSATOB      = 0
      INBSATGEO     = 0
!      INBGEOWIND    = 0
      INBBUOY       = 0
      INBBATHY      = 0
      INBTESAC      = 0
      INBTEMP       = 0
      INBTEMPSHIP   = 0
      INBTEMPDROP   = 0
      INBTEMPMOBIL  = 0
      INBPILOT      = 0
      INBPILOTSHIP  = 0
      INBPILOTMOBIL = 0
      INBEUROPROFIL = 0
      INBPROFILER   = 0
      INBSATEM      = 0
      INBTOVS120    = 0
      INBATOVS      = 0
      INBSSMI       = 0
      INBSSMICE     = 0
      INBERS1UWI    = 0
!      INBQUIKSCAT   = 0
      INBCYCLONE    = 0
      INBTHIRS      = 0
      INBTMSU       = 0
      INBTAMSUA     = 0
      INBTAMSUB     = 0
      INBAIRSBT     = 0
      INBGPSSOL     = 0
      INBPAOBREU    = 0

      INBWAG        = 0

      INEWACAR      = -1

      ZLATNAUS      = -50.
      ZLATSAUS      = -10.
      ZLONOAUS      = 110.
      ZLONEAUS      = 160.

      CLNOEC        = '      '
      IPLEIN        = 0
      INBSATEL      = 0
      I_LISTE_SAT   = 0
      
      LMERIDIAN     = .FALSE.

      CLTYPGEN(:)=''
!-----------------------------------------------------------------------

!  Extractions, zone par zone
!  --------------------------

      IF ( NINIT.EQ.0 .AND. .NOT.L_SAUT_DATE ) THEN
        OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',STATUS='UNKNOWN')
        WRITE (NULOBI,*) NDATE,NRESO
        CLOSE (NULOBI)
        IF (LPAOB_REU) THEN
          OPEN (NULOBI,FILE='PAOBREU',FORM='FORMATTED',STATUS='UNKNOWN')
          WRITE (NULOBI,*) NDATE,NRESO
          CLOSE (NULOBI)
        ENDIF
        OPEN (NULRFD,FILE='REFDATA',FORM='FORMATTED',STATUS='UNKNOWN')
        CLOSE (NULRFD)
      ENDIF
      IF ( L_GEOPOINTS ) THEN
        OPEN (NULGEO,FILE='GEOPOINTS',FORM='FORMATTED',STATUS='UNKNOWN')
        WRITE (NULGEO,101)
 101    FORMAT('#GEO',/,'#FORMAT LLV',/,'#DATA')
      ENDIF

      BOUCLE_ZONE_GEO: DO JZ=1,3

        IF ( JZ.EQ.1 .AND. LZONEA ) THEN
          ZLATN = ALANZA
          ZLATS = ALASZA
          ZLONO = ALOOZA
          ZLONE = ALOEZA
        ELSE IF ( JZ.EQ.2 .AND. LZONEB ) THEN
          ZLATN = ALANZB
          ZLATS = ALASZB
          ZLONO = ALOOZB
          ZLONE = ALOEZB
        ELSE IF ( JZ.EQ.3 .AND. LZONEC ) THEN
          ZLATN = ALANZC
          ZLATS = ALASZC
          ZLONO = ALOOZC
          ZLONE = ALOEZC
        ELSE
          CYCLE BOUCLE_ZONE_GEO
        ENDIF

        IF ( ZLATN.GT.90. .OR. ZLATS.LT.-90. .OR. ZLATN.LT.ZLATS .OR.
     &       ZLONO.GT.180. .OR. ZLONO.LT.-180. .OR.
     &       ZLONE.GT.180. .OR. ZLONE.LT.-180.                 ) THEN
          WRITE (NULOUT,102) ZLATN,ZLONO,ZLATS,ZLONE
 102      FORMAT(//,' A T T E N T I O N :  les latitudes doivent',
     &           ' etre comprises entre -90. et +90. ',/,' -----',
     &           '------------    les longitudes doivent etre co',
     &           'mprises entre -180. et 180. ',//,' vous avez d',
     &           'emande :  latitude nord : ',F7.2,'       longi',
     &           'tude ouest : ',F7.2,/,'                      l',
     &           'atitude sud  : ',F7.2,'       longitude est   ',
     &           ': ',F7.2,//,' veuillez corriger ces valeurs er',
     &           'ronees ',//)
          STOP
        ENDIF

        ISY1 = 0
        ISY2 = 0

        IF ( LFTSYSUP ) THEN
          IF ( ZLATN.GT.ZLATNAUS ) THEN
            ISY1 = 1
            IF ( ZLATS.GT.ZLATNAUS .OR.
     &           ( ZLONE.LT.ZLONOAUS.OR.ZLONO.GT.ZLONEAUS ) ) THEN
              ISY2 = 0
            ELSE
              ISY2 = 1
            ENDIF
          ELSE IF ( ZLATN.LT.ZLATSAUS ) THEN
            ISY1 = 1
            ISY2 = 0
          ELSE
            IF ( ZLONO.LT.ZLONOAUS .OR. ZLONE.GT.ZLONEAUS ) THEN
              ISY1 = 1
              IF ( ZLONE.LT.ZLONOAUS .OR. ZLONO.GT.ZLONEAUS ) THEN
                ISY2 = 0
              ELSE
                ISY2 = 1
              ENDIF
            ELSE
              ISY1 = 0
              ISY2 = 1
            ENDIF
          ENDIF
        ELSE
          ISY1 = 1
          ISY2 = 0
        ENDIF
!  Extraction des OBS de NAMEL_1 par ordre decroissant de volume en Mo
!  BUOY - ACAR - SYNOP - AMDAR
!  TEMP - PILOT - RADOMEH - SHIP
!  SYNOR - TEMPDROP - AIREP - TESAC
!  TEMPMOBIL - TEMPSHIP - PILOTSHIP - BATHY

!  Extraction des GPSSOL
!  -----------------------

            IF ( LGPSSOL .AND. NBGPSSOL.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'GPSSOL    '
               CALL EXT_GPSSOL(NBGPSSOL,INBGPSSOL,CLTYPM,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_GPSSOL))
               IF ( INGPSSOL.GT.0 ) INBOBS = INBOBS + INBGPSSOL
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des BUOY
!  -------------------

            IF ( LBUOY .AND. NBBUOY.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'BUOY      '
               CALL EXT_BUOY(NBBUOY,INBBUOY,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_BUOY))
               IF ( INBBUOY.GT.0 ) INBOBS = INBOBS + INBBUOY
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des ACAR
!  -------------------

            IF ( LACAR .AND. NBACAR.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'ACAR      '
               CALL EXT_ACAR(NBACAR,INBACAR,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_ACAR))
               IF ( INBACAR.GT.0 ) INBOBS = INBOBS + INBACAR
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des SYNOP
!  --------------------

          IF ( LSYNOP .AND. NBSYNOP.GT.0 ) THEN
            CLTYPM = 'SYNOP     '
            CLTYPM2 = 'SYNOPA    '

            IF ( ISY1.EQ.1 ) THEN
              IF ( NINIT.EQ.0 )
     &          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                POSITION='APPEND',STATUS='UNKNOWN')
              IAUST = 0
!FGFG
              CALL EXT_SYNOP(NBSYNOP,INBSYNOP,CLTYPM,CLTYPM2,INBWAG,
     &          IAUST,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SYNOP))
              IF ( INBSYNOP.GT.0 ) INBOBS = INBOBS + INBSYNOP
              IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF
            IF ( ISY2.EQ.1 ) THEN
              IF ( NINIT.EQ.0 )
     &          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                POSITION='APPEND',STATUS='UNKNOWN')
              IAUST = 1
!FGFG
              CALL EXT_SYNOP(NBSYNOP,INBSYNOPA,CLTYPM,CLTYPM2,INBWAG,
     &          IAUST,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SYNOP))
              IF ( INBSYNOPA.GT.0 ) THEN
                INBOBS = INBOBS + INBSYNOPA
                         INBSYNOP = INBSYNOP + INBSYNOPA
              ENDIF
              IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF
          ENDIF

!  Extraction des AMDAR
!  --------------------

            IF ( LAMDAR .AND. NBAMDAR.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'AMDAR     '
               CALL EXT_AIREP(NBAMDAR,INBAMDAR,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_AMDAR))
               IF ( INBAMDAR.GT.0 ) INBOBS = INBOBS + INBAMDAR
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TEMP
!  -------------------

            IF ( LTEMP .AND. NBTEMP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TEMP      '
               CLTYPM2 = 'TEMPA     '
!FGFG
               CALL EXT_TEMP(NBTEMP,INBTEMP,CLTYPM,CLTYPM2,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TEMP))
               IF ( INBTEMP.GT.0 ) INBOBS = INBOBS + INBTEMP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des PILOT
!  --------------------

            IF ( LPILOT .AND. NBPILOT.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'PILOT     '
               CLTYPM2 = 'PILOTA    '
!FGFG
               CALL EXT_PILOT(NBPILOT,INBPILOT,CLTYPM,CLTYPM2,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_PILOT))
               IF ( INBPILOT.GT.0 ) INBOBS = INBOBS + INBPILOT
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees RADOMEH
!  ------------------------------

            IF ( LRADOMEH .AND. NBRADOMEH.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM     = 'RADOMEH   '
               CALL EXT_RADOMEH(NBRADOMEH,INBRADOMEH,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_RADOMEH))
               IF ( INBRADOMEH.GT.0 ) INBOBS = INBOBS + INBRADOMEH
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des SHIP
!  -------------------

            IF ( LSHIP .AND. NBSHIP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'SHIP      '
               CLTYPM2 = 'SHIPA     '
               IAUST = 0
!FGFG
               CALL EXT_SYNOP(NBSHIP,INBSHIP,CLTYPM,CLTYPM2,INBWAG,
     &            IAUST,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SHIP))
               IF ( INBSHIP.GT.0 ) INBOBS = INBOBS + INBSHIP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des SYNOR
!  --------------------

            IF ( LSYNOR .AND. NBSYNOR.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'SYNOR     '
               CALL EXT_SYNOR(NBSYNOR,INBSYNOR,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SYNOR))
               IF ( INBSYNOR.GT.0 ) INBOBS = INBOBS + INBSYNOR
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TEMPDROP
!  -----------------------

            IF ( LTEMPDROP .AND. NBTEMPDROP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TEMPDROP  '
               CLTYPM2 = 'TEMPDROPA '
!FGFG
               CALL EXT_TEMP(NBTEMPDROP,INBTEMPDROP,CLTYPM,CLTYPM2,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TEMPDROP))
               IF ( INBTEMPDROP.GT.0 ) INBOBS = INBOBS + INBTEMPDROP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des AIREP
!  --------------------

            IF ( LAIREP .AND. NBAIREP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'AIREP     '
               CALL EXT_AIREP(NBAIREP,INBAIREP,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_AIREP))
               IF ( INBAIREP.GT.0 ) INBOBS = INBOBS + INBAIREP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TESAC
!  --------------------

            IF ( LTESAC .AND. NBTESAC.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TESAC     '
               CALL EXT_TESAC(NBTESAC,INBTESAC,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TESAC))
               IF ( INBTESAC.GT.0 ) INBOBS = INBOBS + INBTESAC
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TEMPMOBIL
!  ------------------------

            IF ( LTEMPMOBIL .AND. NBTEMPMOBIL.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TEMPMOBIL '
               CLTYPM2 = 'TEMPMOBILA'
!FGFG
               CALL EXT_TEMP(NBTEMPMOBIL,INBTEMPMOBIL,CLTYPM,CLTYPM2,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TEMPMOBIL))
               IF ( INBTEMPMOBIL.GT.0 ) INBOBS = INBOBS + INBTEMPMOBIL
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TEMPSHIP
!  -----------------------

            IF ( LTEMPSHIP .AND. NBTEMPSHIP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TEMPSHIP  '
               CLTYPM2 = 'TEMPSHIPA '
!FGFG
               CALL EXT_TEMP(NBTEMPSHIP,INBTEMPSHIP,CLTYPM,CLTYPM2,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TEMPSHIP))
               IF ( INBTEMPSHIP.GT.0 ) INBOBS = INBOBS + INBTEMPSHIP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des PILOTSHIP
!  ------------------------

            IF ( LPILOTSHIP .AND. NBPILOTSHIP.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'PILOTSHIP '
               CLTYPM2 = 'PILOTSHIPA'
!FGFG
               CALL EXT_PILOT(NBPILOTSHIP,INBPILOTSHIP,CLTYPM,CLTYPM2,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_PILOTSHIP))
               IF ( INBPILOTSHIP.GT.0 ) INBOBS = INBOBS + INBPILOTSHIP
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des BATHY
!  --------------------

            IF ( LBATHY .AND. NBBATHY.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'BATHY     '
               CALL EXT_BATHY(NBBATHY,INBBATHY,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_BATHY))
               IF ( INBBATHY.GT.0 ) INBOBS = INBOBS + INBBATHY
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des OBS de NAMEL_2 et 3 par ordre decroissant de volume
!  en Mo 
!  TOVSAMSUB - AIRSBT - TOVSAMSUA - TOVSHIRS - GEOWIND - SATOB
!  EUROPROFIL - PROFILER

!  Extraction des donnees TOVSAMSUB
!  --------------------------------

            IF ( LTOVSAMSUB .AND. NBTOVSAMSUB.GT.0 ) THEN
              IF ( NINIT.EQ.0 )
     &          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                POSITION='APPEND',STATUS='UNKNOWN')
              CLTYPM     = 'TOVSAMSUB '
 
! donnees BRACKNELL

              IF ( L_TAMSUB_BRACK ) THEN
                CL_CODPRO  = ' 74'
                ZLATNP     = ZLATN
                ZLATSP     = ZLATS
                ZLONOP     = ZLONO
                ZLONEP     = ZLONE
                INBT       = NINT( ( ZLATN - ZLATS ) / 36. )
                INBTAMSUBE = MIN( NBTOVSAMSUB , 600000 )
                DO JAMSUB=1,INBT
                  IF ( INBTAMSUBE.GT.NBTOVSAMSUB ) CYCLE
                  ZLATNP  = ZLATN - (JAMSUB-1)*36.
                  ZLATSP  = ZLATNP - 35.999999
                  IF ( ZLATNP.LE.-90. .OR. ZLATSP.GE.90. ) CYCLE
                  CALL EXT_TOVSAMSUB(CL_CODPRO,INBTAMSUBE,INBTAMSUBP,
     &                               CLTYPM,INBWAG,ZLATNP,ZLATSP,
     &                               ZLONO,ZLONE,IPLEIN(N_TOVSAMSUB))
                  IF ( INBTAMSUBP.GT.0 ) THEN
                    INBTAMSUB = INBTAMSUB + INBTAMSUBP
                    INBOBS    = INBOBS + INBTAMSUBP
                  ENDIF
                ENDDO
              ENDIF
 
! donnees LANNION

              IF ( L_TAMSUB_LANNION .AND. ZLATN.GT.0. ) THEN
                CL_CODPRO  = '211'
                ZLATNP     = ZLATN
                ZLATSP     = ZLATS
                ZLONOP     = ZLONO
                ZLONEP     = ZLONE
                IF ( ZLATS.LT.0.      ) ZLATSP = 0.
                IF ( ZLONO.LT.-70.    ) ZLONOP = -70.
                IF ( ZLONE.GT.50.     ) ZLONEP = 50.
                IF ( ZLONOP.GT.ZLONEP ) ZLONOP = ZLONEP
                CALL EXT_TOVSAMSUB(CL_CODPRO,NBTOVSAMSUB,INBTAMSUBP,
     &            CLTYPM,INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUB))
                  IF ( INBTAMSUBP.GT.0 ) THEN
                    INBTAMSUB = INBTAMSUB + INBTAMSUBP
                    INBOBS    = INBOBS + INBTAMSUBP
                  ENDIF
              ENDIF
 
! donnees CEPMMT

              IF ( L_TAMSUB_CEP ) THEN
                CL_CODPRO  = ' 98'
                ZLATNP     = ZLATN
                ZLATSP     = ZLATS
                ZLONOP     = ZLONO
                ZLONEP     = ZLONE
                INBT       = NINT( ( ZLATN - ZLATS ) / 90. )
                INBTAMSUBE = MIN( NBTOVSAMSUB , 600000 )
                DO JAMSUB=1,INBT
                  IF ( INBTAMSUBE.GE.NBTOVSAMSUB ) CYCLE
                  ZLATNP  = ZLATN - (JAMSUB-1)*90.
                  ZLATSP  = ZLATNP - 89.999999
                  IF ( ZLATNP.LE.-90. .OR. ZLATSP.GE.90. ) CYCLE
                  CALL EXT_TOVSAMSUB(CL_CODPRO,INBTAMSUBE,INBTAMSUBP,
     &                               CLTYPM,INBWAG,ZLATNP,ZLATSP,
     &                               ZLONO,ZLONE,IPLEIN(N_TOVSAMSUB))
                  IF ( INBTAMSUBP.GT.0 ) THEN
                    INBTAMSUB = INBTAMSUB + INBTAMSUBP
                    INBOBS    = INBOBS + INBTAMSUBP
                  ENDIF
                ENDDO
              ENDIF
 
! donnees EUMETSAT

              IF ( L_TAMSUB_EUMETSAT .AND. ZLATN.GT.0. ) THEN
                CL_CODPRO  = '254'
                ZLATSP     = ZLATS
                IF ( ZLATS.LT.0. ) ZLATSP = 0.
                CALL EXT_TOVSAMSUB(CL_CODPRO,NBTOVSAMSUB,INBTAMSUBP,
     &            CLTYPM,INBWAG,ZLATN,ZLATSP,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUB))
                  IF ( INBTAMSUBP.GT.0 ) THEN
                    INBTAMSUB = INBTAMSUB + INBTAMSUBP
                    INBOBS    = INBOBS + INBTAMSUBP
                  ENDIF
              ENDIF
              IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees SSMI
!  ---------------------------

            IF ( LSSMI .AND. NBSSMI.GT.0 ) THEN
              CLTYPM   = 'SSMI      '
              INBT     = ( ZLATN - ZLATS ) / 45 + 1
              INBSSMIE = MIN( NBSSMI , 500000 )
              INBSSMIP = 0
              DO JSSMI=1,INBT
                IF ( INBSSMI.GE.NBSSMI ) CYCLE
                ZLATNP = ZLATN - (JSSMI-1)*45.
                ZLATSP = ZLATNP - 44.99999
                IF ( ZLATNP.LE.-90. .OR. ZLATSP.GE.90. ) CYCLE
                IF ( NINIT.EQ.0 )
     &            OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                  POSITION='APPEND',STATUS='UNKNOWN')
                CALL EXT_SSMI(INBSSMIE,INBSSMIP,CLTYPM,INBWAG,
     &            ZLATNP,ZLATSP,ZLONO,ZLONE,INBSATEL,IPLEIN(N_SSMI))
                IF ( INBSSMIP.GT.0 ) THEN
                  INBSSMI = INBSSMI + INBSSMIP
                  INBOBS  = INBOBS + INBSSMIP
                ENDIF
                IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
              ENDDO
              DO J=1,JP_MAX_NB_SAT
                CLNBSAT(J) = '        '
                IF ( INBSATEL(J).NE.0 )
     &            WRITE (CLNBSAT(J),'(I8.0)') INBSATEL(J)
              ENDDO
              WRITE (NULOUT,103) CLNBSAT
 103          FORMAT(//,' extraction des donnees SSMI ',/,1X,27('-'),
     &               //,'   numeros des satellites  :',9X,'F13/246 ',
     &               '   F14/247    F15/247    autres',//,
     &               '   nombres de messages extraits  : ',
     &               4(A8,3X),/)
            ENDIF

!  Extraction des AIRSBT
!  ---------------------

            IF ( LAIRSBT .AND. NBAIRSBT.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'AIRSBT    '
               CALL EXT_AIRSBT(NBAIRSBT,INBAIRSBT,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_AIRSBT))
               IF ( INBAIRSBT.GT.0 ) INBOBS = INBOBS + INBAIRSBT
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees TOVSAMSUA
!  --------------------------------

!  Forcages eventuels (uniquement si L_CUTOFF_C ou L_CUTOFF_L)
!  -----------------------------------------------------------

!    si L_CUTOFF_C 

!      -> extraction des TOVSAMSUA Bracknell, EUMETSAT et Lannion
!      -> extraction des TOVSHIRS  Bracknell

!    si L_CUTOFF_L 

!      -> extraction des TOVSAMSUA Bracknell
!           si nb TOVSAMSUA Bracknell = 0, extraction EUMETSAT et Lannion
!      -> extraction des TOVSHIRS  Bracknell

            IF ( LTOVSAMSUA .AND. NBTOVSAMSUA.GT.0 ) THEN
              IF ( NINIT.EQ.0 )
     &          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                POSITION='APPEND',STATUS='UNKNOWN')
              CLTYPM     = 'TOVSAMSUA '

! donnees BRACKNELL

              I_NB_TA_BK = 0
              IF ( L_TAMSUA_BRACK ) THEN
                CL_CODPRO  = ' 74'
                CALL EXT_TOVSAMSUA(CL_CODPRO,NBTOVSAMSUA,INBTAMSUA,
     &            CLTYPM,INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUA))
                IF ( INBTAMSUA.GT.0 ) INBOBS = INBOBS + INBTAMSUA
                I_NB_TA_BK = INBTAMSUA
              ENDIF
              IF ( ( L_CUTOFF_L .AND. I_NB_TA_BK.EQ.0 )   .OR.
     &             ( L_TAMSUA_LANNION .AND. ZLATN.GT.0. )      ) THEN
                CL_CODPRO  = '211'
                ZLATNP     = ZLATN
                ZLATSP     = ZLATS
                ZLONOP     = ZLONO
                ZLONEP     = ZLONE
                IF ( ZLATS.LT.0.      ) ZLATSP = 0.
                IF ( ZLONO.LT.-70.    ) ZLONOP = -70.
                IF ( ZLONE.GT.50.     ) ZLONEP = 50.
                IF ( ZLONOP.GT.ZLONEP ) ZLONOP = ZLONEP
                CALL EXT_TOVSAMSUA(CL_CODPRO,NBTOVSAMSUA,INBTAMSUA,
     &            CLTYPM,INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUA))
                IF ( INBTAMSUA.GT.0 ) INBOBS = INBOBS + INBTAMSUA
              ENDIF
 
! donnees CEPMMT

             IF ( L_TAMSUA_CEP ) THEN
                CL_CODPRO  = ' 98'
                CALL EXT_TOVSAMSUA(CL_CODPRO,NBTOVSAMSUA,INBTAMSUA,
     &            CLTYPM,INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUA))
                IF ( INBTAMSUA.GT.0 ) INBOBS = INBOBS + INBTAMSUA
              ENDIF
              IF ( ( L_CUTOFF_L .AND. I_NB_TA_BK.EQ.0 )    .OR.
     &             ( L_TAMSUA_EUMETSAT .AND. ZLATN.GT.0. )      ) THEN
                CL_CODPRO  = '254'
                ZLATSP     = ZLATS
                IF ( ZLATS.LT.0. ) ZLATSP = 0.
                CALL EXT_TOVSAMSUA(CL_CODPRO,NBTOVSAMSUA,INBTAMSUA,
     &            CLTYPM,INBWAG,ZLATN,ZLATSP,ZLONO,ZLONE,
     &            IPLEIN(N_TOVSAMSUA))
                IF ( INBTAMSUA.GT.0 ) INBOBS = INBOBS + INBTAMSUA
              ENDIF
              IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees TOVSHIRS
!  -------------------------------

            IF ( LTOVSHIRS .AND. NBTOVSHIRS.GT.0 ) THEN
              CLTYPM    = 'TOVSHIRS  '

              IF ( LHIRSECH .AND. NHIRSSAUT.LE.0 ) THEN
                ZP_DELTA      = 125000.
                N_NB_BOITES   = 0
                I_NB_BDL_DEMI = NINT( (RPI/2.) * RA / ZP_DELTA )
                Z_PAS_RAD_LAT = RPI/2. / I_NB_BDL_DEMI
                Z_PAS_DEG_LAT = 90. / I_NB_BDL_DEMI
                DO J=1,I_NB_BDL_DEMI
                  Z_CIRCUM    = 2*RPI*COS(Z_PAS_RAD_LAT*(J-1))*RA
                  N_NB_BOITES = N_NB_BOITES + NINT(Z_CIRCUM/ZP_DELTA)
                ENDDO
                N_NB_BOITES = N_NB_BOITES * 2
                N_NB_BDL    = I_NB_BDL_DEMI * 2
                I_MOITIE = N_NB_BOITES / 2
                JN = I_MOITIE + 1
                JS = I_MOITIE
                DO JBDL=1,I_NB_BDL_DEMI
                  Z_CIRCUM    = 2*RPI*COS(Z_PAS_RAD_LAT*(JBDL-1))*RA
                  I_NBBO1BAND = NINT( Z_CIRCUM/ZP_DELTA )

                  M_NO_BBDL(I_NB_BDL_DEMI+JBDL  ,1) = JN
                  M_NO_BBDL(I_NB_BDL_DEMI+1-JBDL,1) = JS + 1-I_NBBO1BAND
                  M_NO_BBDL(I_NB_BDL_DEMI+JBDL  ,2) = I_NBBO1BAND
                  M_NO_BBDL(I_NB_BDL_DEMI+1-JBDL,2) = I_NBBO1BAND

                  Z_LATBN = Z_PAS_DEG_LAT*(JBDL-1)
                  Z_LATBS = Z_PAS_DEG_LAT*(JBDL)

                  DO J=1,I_NBBO1BAND
                    Z_PAS_DEG_LON = 360. / I_NBBO1BAND
                    A_LLBOX(JN,1) = Z_LATBN
                    A_LLBOX(JN,2) = Z_LATBS
                    A_LLBOX(JN,3) = -180. + Z_PAS_DEG_LON*(J-1)
                    A_LLBOX(JN,4) = -180. + Z_PAS_DEG_LON*(J)
                    A_LLBOX(JS,1) = -1.*A_LLBOX(JN,2)
                    A_LLBOX(JS,2) = -1.*A_LLBOX(JN,1)
                    A_LLBOX(JS,3) = A_LLBOX(JN,3)
                    A_LLBOX(JS,4) = A_LLBOX(JN,4)
                    JN = JN + 1
                    JS = JS - 1
                  ENDDO
                ENDDO
              ENDIF

! donnees BRACKNELL

              IF ( L_THIRS_BRACK ) THEN
                CL_CODPRO  = ' 74'

! definition de l'extraction par morceaux
		IPASLON    = 180
		IPASLAT    = 0
		
		IF (ZLATN < ZLATS) THEN
		   ZLATNP = MIN(ZLATS,90.)
		   ZLATSP = MAX(ZLATN,-90.)
		ELSE
                   ZLATNP = MIN(ZLATN,90.)
                   ZLATSP = MAX(ZLATS,-90.)
		ENDIF
                IF (IPASLAT == 0) THEN
		   ITERLAT = 1
		ELSE
		   ITERLAT = CEILING((ZLATN-ZLATS)/IPASLAT)
		ENDIF

                ZLONOP     = ZLONO
                ZLONEP     = ZLONE

                IF (ZLONOP > ZLONEP) THEN
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING((360.-(ZLONOP-ZLONEP))/IPASLON)
		  ENDIF
		  LMERIDIAN = .TRUE.
                ELSE
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING(ABS(ZLONOP-ZLONEP)/IPASLON)
		  ENDIF
		  LMERIDIAN = .FALSE.
		ENDIF

                IF ( LHIRSECH .AND. NHIRSSAUT.LE.0 ) THEN
                  INBTHIRSE = MIN( NBTOVSHIRS , 500000 )
                  DO JLON=1,ITERLON
                    DO JLAT=1,ITERLAT
                      IF ( INBTHIRS.GT.NBTOVSHIRS ) CYCLE

                      CALL DECOUP_ZONE(ZLATNP, ZLATSP, IPASLAT, JLAT,
     &                                 ZLONOP, ZLONEP, IPASLON, JLON,
     &                                 ZLATBN, ZLATBS, ZLONBO , ZLONBE,
     &                                 LMERIDIAN)

                      IF ( NINIT.EQ.0 )
     &                OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                      POSITION='APPEND',STATUS='UNKNOWN')
                      CALL EXT_TOVSHIRS_ECH
     &                     (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                     CLTYPM,INBWAG,ZLATBN,ZLATBS,ZLONBO,ZLONBE,
     &                     N_NB_BOITES,N_NB_BDL,A_LLBOX,M_NO_BBDL,
     &                     IPLEIN(N_TOVSHIRS))
                      IF ( INBTHIRSP.GT.0 ) THEN
                         INBTHIRS = INBTHIRS + INBTHIRSP
                         INBOBS   = INBOBS + INBTHIRSP
                      ENDIF
                      IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
                    ENDDO
                  ENDDO
                ELSE
                  INBTHIRSE = MIN( NBTOVSHIRS , 500000 )
                  DO JLON=1,ITERLON
                    DO JLAT=1,ITERLAT
                      IF ( INBTHIRS.GE.NBTOVSHIRS ) CYCLE

                      CALL DECOUP_ZONE(ZLATNP, ZLATSP, IPASLAT, JLAT,
     &                                 ZLONOP, ZLONEP, IPASLON, JLON,
     &                                 ZLATBN, ZLATBS, ZLONBO , ZLONBE,
     &                                 LMERIDIAN)

                      IF ( NINIT.EQ.0 )
     &                   OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                         POSITION='APPEND',STATUS='UNKNOWN')
                      CALL EXT_TOVSHIRS
     &                     (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                     CLTYPM,INBWAG,ZLATBN,ZLATBS,ZLONBO,ZLONBE,
     &                     IPLEIN(N_TOVSHIRS))
                      IF ( INBTHIRSP.GT.0 ) THEN
                         INBTHIRS = INBTHIRS + INBTHIRSP
                         INBOBS   = INBOBS + INBTHIRSP
                      ENDIF
                      IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
                    ENDDO
                  ENDDO
                ENDIF
              ENDIF

! donnees LANNION

              IF ( L_THIRS_LANNION ) THEN 
		IF (ZLATN < ZLATS) THEN
		   ZLATNP = MIN(ZLATS,90.)
		   ZLATSP = MAX(ZLATN,-90.)
		ELSE
                   ZLATNP = MIN(ZLATN,90.)
                   ZLATSP = MAX(ZLATS,-90.)
		ENDIF
                IF (ZLATNP.GT.0.) THEN
                  CL_CODPRO  = '211'
                  ZLONOP     = ZLONO
                  ZLONEP     = ZLONE
                  INBTHIRSE  = MIN( NBTOVSHIRS , 500000 )
                  IF ( ZLATSP.LT.  0.   ) ZLATSP = 0.
!                 IF ( ZLONOP.LT.-70.   ) ZLONOP = -70.
!                 IF ( ZLONEP.GT. 50.   ) ZLONEP =  50.
                  IF ( ZLONOP.GT.ZLONEP ) ZLONOP = ZLONEP
                  IF ( NINIT.EQ.0 )
     &              OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                    POSITION='APPEND',STATUS='UNKNOWN')
                  IF ( LHIRSECH .AND. NHIRSSAUT.LE.0 ) THEN
                    CALL EXT_TOVSHIRS_ECH
     &                   (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                   CLTYPM,INBWAG,ZLATNP,ZLATSP,ZLONOP,ZLONEP,
     &                   N_NB_BOITES,N_NB_BDL,A_LLBOX,M_NO_BBDL,
     &                   IPLEIN(N_TOVSHIRS))
                  ELSE
                    CALL EXT_TOVSHIRS
     &                   (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                   CLTYPM,INBWAG,ZLATNP,ZLATSP,ZLONOP,ZLONEP,
     &                   IPLEIN(N_TOVSHIRS))
                  ENDIF
                  IF ( INBTHIRSP.GT.0 ) THEN
                    INBTHIRS = INBTHIRS + INBTHIRSP
                    INBOBS   = INBOBS + INBTHIRSP
                  ENDIF
                  IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
		ENDIF
              ENDIF

! donnees EUMETSAT

              IF ( L_THIRS_EUMETSAT ) THEN
                CL_CODPRO  = '254'

! definition de l'extraction par morceaux
		IPASLON    = 180
		IPASLAT    = 0
		
		IF (ZLATN < ZLATS) THEN
		   ZLATNP = MIN(ZLATS,90.)
		   ZLATSP = MAX(ZLATN,-90.)
		ELSE
                   ZLATNP = MIN(ZLATN,90.)
                   ZLATSP = MAX(ZLATS,-90.)
		ENDIF
                IF (IPASLAT == 0) THEN
		   ITERLAT = 1
		ELSE
		   ITERLAT = CEILING((ZLATN-ZLATS)/IPASLAT)
		ENDIF

                ZLONOP     = ZLONO
                ZLONEP     = ZLONE

                IF (ZLONOP > ZLONEP) THEN
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING((360.-(ZLONOP-ZLONEP))/IPASLON)
		  ENDIF
		  LMERIDIAN = .TRUE.
                ELSE
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING(ABS(ZLONOP-ZLONEP)/IPASLON)
		  ENDIF
		  LMERIDIAN = .FALSE.
		ENDIF

                INBTHIRSE  = MIN( NBTOVSHIRS , 500000 )
                  DO JLON=1,ITERLON
                    DO JLAT=1,ITERLAT
                      IF ( INBTHIRS.GT.NBTOVSHIRS ) CYCLE

                      CALL DECOUP_ZONE(ZLATNP, ZLATSP, IPASLAT, JLAT,
     &                                 ZLONOP, ZLONEP, IPASLON, JLON,
     &                                 ZLATBN, ZLATBS, ZLONBO , ZLONBE,
     &                                 LMERIDIAN)

                      IF ( NINIT.EQ.0 )
     &                OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                      POSITION='APPEND',STATUS='UNKNOWN')
!                     IF ( ZLATS.LT.0. ) ZLATSP = 0.
                      IF ( LHIRSECH .AND. NHIRSSAUT.LE.0 ) THEN
                         CALL EXT_TOVSHIRS_ECH(CL_CODPRO,
     &                        INBTHIRSE,INBTHIRSP,CLTYPM,INBWAG,ZLATBN,
     &                        ZLATBS,ZLONBO,ZLONBE,N_NB_BOITES,
     &                        N_NB_BDL,A_LLBOX,M_NO_BBDL,
     &                        IPLEIN(N_TOVSHIRS))
                      ELSE
                         CALL EXT_TOVSHIRS
     &                        (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                        CLTYPM,INBWAG,ZLATBN,ZLATBS,ZLONBO,ZLONBE,
     &                        IPLEIN(N_TOVSHIRS))
                      ENDIF
                      IF ( INBTHIRSP.GT.0 ) THEN
                         INBTHIRS = INBTHIRS + INBTHIRSP
                         INBOBS   = INBOBS + INBTHIRSP
                      ENDIF
                      IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
                   ENDDO
                ENDDO
              ENDIF

! donnees CEPMMT

              IF ( L_THIRS_CEP ) THEN
                CL_CODPRO  = ' 98'

! definition de l'extraction par morceaux
		IPASLON    = 180
		IPASLAT    = 0
		
		IF (ZLATN < ZLATS) THEN
		   ZLATNP = MIN(ZLATS,90.)
		   ZLATSP = MAX(ZLATN,-90.)
		ELSE
                   ZLATNP = MIN(ZLATN,90.)
                   ZLATSP = MAX(ZLATS,-90.)
		ENDIF
                IF (IPASLAT == 0) THEN
		   ITERLAT = 1
		ELSE
		   ITERLAT = CEILING((ZLATN-ZLATS)/IPASLAT)
		ENDIF

                ZLONOP     = ZLONO
                ZLONEP     = ZLONE

                IF (ZLONOP > ZLONEP) THEN
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING((360.-(ZLONOP-ZLONEP))/IPASLON)
		  ENDIF
		  LMERIDIAN = .TRUE.
                ELSE
                  IF (IPASLON == 0) THEN
		    ITERLON = 1
		  ELSE
		    ITERLON = CEILING(ABS(ZLONOP-ZLONEP)/IPASLON)
		  ENDIF
		  LMERIDIAN = .FALSE.
		ENDIF

                INBTHIRSE  = MIN( NBTOVSHIRS , 500000 )
                DO JLON=1,ITERLON
                  DO JLAT=1,ITERLAT
                    IF ( INBTHIRS.GT.NBTOVSHIRS ) CYCLE

                    CALL DECOUP_ZONE(ZLATNP, ZLATSP, IPASLAT, JLAT,
     &                                 ZLONOP, ZLONEP, IPASLON, JLON,
     &                                 ZLATBN, ZLATBS, ZLONBO , ZLONBE,
     &                                 LMERIDIAN)

                    IF ( NINIT.EQ.0 )
     &              OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                    POSITION='APPEND',STATUS='UNKNOWN')
                    IF ( LHIRSECH .AND. NHIRSSAUT.LE.0 ) THEN
                       CALL EXT_TOVSHIRS_ECH
     &                      (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                      CLTYPM,INBWAG,ZLATBN,ZLATBS,ZLONBO,ZLONBE,
     &                      N_NB_BOITES,N_NB_BDL,A_LLBOX,M_NO_BBDL,
     &                      IPLEIN(N_TOVSHIRS))
                    ELSE
                       CALL EXT_TOVSHIRS
     &                      (CL_CODPRO,INBTHIRSE,INBTHIRSP,
     &                      CLTYPM,INBWAG,ZLATBN,ZLATBS,ZLONBO,ZLONBE,
     &                      IPLEIN(N_TOVSHIRS))
                    ENDIF
                    IF ( INBTHIRSP.GT.0 ) THEN
                       INBTHIRS = INBTHIRS + INBTHIRSP
                       INBOBS   = INBOBS + INBTHIRSP
                    ENDIF
                    IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
                  ENDDO
                ENDDO
              ENDIF
            ENDIF

!  Extraction des GEOWIND
!  ----------------------

!            IF ( LGEOWIND .AND. NBGEOWIND.GT.0 ) THEN
!               IF ( NINIT.EQ.0 )
!     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
!     &                 POSITION='APPEND',STATUS='UNKNOWN')
!               CLTYPM = 'GEOWIND   '

! recherche de Meteosat-8 (alias MSG)

!               ILELA     = 0
!               IVAN      = 0
!               INBNOMSG  = 0
!               DO J=1,MNBSATSEL(N_GEOWIND)
!                 IF ( MNOSATSEL(N_GEOWIND,J).EQ.55 ) THEN
!                   ILELA = J
!                   I_LISTE_SAT(MNBSATSEL(N_GEOWIND)) = 55
!                 ELSE
!                   IVAN = IVAN + 1
!                   I_LISTE_SAT(IVAN) = MNOSATSEL(N_GEOWIND,J)
!                   INBNOMSG = INBNOMSG + MNBOBS(N_GEOWIND,J)
!                 ENDIF
!               ENDDO

! extractions

!               IF ( ILELA.NE.0 ) THEN
!                 INBGEOWIND1 = 0
!                 INBGEOWIND2 = 0
!                 IF ( IVAN.GE.1 ) THEN
!                   I_NB_SAT  = MNBSATSEL(N_GEOWIND) - 1
!                   I_NB_GEOW = MAX( INBNOMSG , 200000 )
!                   CALL EXT_GEOWIND(I_NB_SAT,I_LISTE_SAT,I_NB_GEOW,
!     &               INBGEOWIND1,CLTYPM,INBWAG,
!     &               ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_GEOWIND))
!                   IF ( INBGEOWIND1.GT.0 ) INBOBS = INBOBS + INBGEOWIND1
!                 ENDIF
!                 I_NB_SAT  = 1
!                 I_NB_GEOW = MNBOBS(N_GEOWIND,ILELA)
!                 CALL EXT_GEOWIND(I_NB_SAT,
!     &             I_LISTE_SAT(MNBSATSEL(N_GEOWIND)),I_NB_GEOW,
!     &             INBGEOWIND2,CLTYPM,INBWAG,
!     &             ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_GEOWIND))
!                 IF ( INBGEOWIND2.GT.0 ) INBOBS = INBOBS + INBGEOWIND2
!                 INBGEOWIND = INBGEOWIND1 + INBGEOWIND2
!                 IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
!               ELSE
!                 CALL EXT_GEOWIND(MNBSATSEL(N_GEOWIND),I_LISTE_SAT,
!     &             NBGEOWIND,INBGEOWIND,CLTYPM,INBWAG,
!     &             ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_GEOWIND))
!                 IF ( INBGEOWIND.GT.0 ) INBOBS = INBOBS + INBGEOWIND
!                 IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
!               ENDIF
!            ENDIF


!  Extraction des SATOB
!  --------------------

            IF ( LSATOB .AND. NBSATOB.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'SATOB     '
               CALL EXT_SATOB(NBSATOB,INBSATOB,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SATOB))
               IF ( INBSATOB.GT.0 ) INBOBS = INBOBS + INBSATOB
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des EUROPROFIL
!  -------------------------

            IF ( LEUROPROFIL .AND. NBEUROPROFIL.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'EUROPROFIL'
               CALL EXT_EUROPROFIL(NBEUROPROFIL,INBEUROPROFIL,CLTYPM,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_EUROPROFIL))
               IF ( INBEUROPROFIL.GT.0 ) INBOBS = INBOBS + INBEUROPROFIL
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des PROFILER
!  -----------------------

            IF ( LPROFILER .AND. NBPROFILER.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'PROFILER  '
               CALL EXT_PROFILER(NBPROFILER,INBPROFILER,CLTYPM,
     &           INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_PROFILER))
               IF ( INBPROFILER.GT.0 ) INBOBS = INBOBS + INBPROFILER
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF



!  Extraction des autres OBS par ordre decroissant de volume en Mo

!  Extraction des SATGEO
!  ---------------------

            IF ( LSATGEO .AND. NBSATGEO.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'SATGEO    '
               CALL EXT_SATGEO(NBSATGEO,INBSATGEO,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SATGEO))
               IF ( INBSATGEO.GT.0 ) INBOBS = INBOBS + INBSATGEO
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des SATEM
!  --------------------

            IF ( LSATEM .AND. NBSATEM.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'SATEM     '
               CALL EXT_SATEM(NBSATEM,INBSATEM,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_SATEM))
               IF ( INBSATEM.GT.0 ) INBOBS = INBOBS + INBSATEM
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des PILOTMOBIL
!  -------------------------

            IF ( LPILOTMOBIL .AND. NBPILOTMOBIL.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'PILOTMOBIL'
               CALL EXT_PILOT(NBPILOTMOBIL,INBPILOTMOBIL,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_PILOTMOBIL))
               IF ( INBPILOTMOBIL.GT.0 ) INBOBS = INBOBS + INBPILOTMOBIL
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des TOVS
!  -------------------

            IF ( LTOVS120 .AND. NBTOVS120.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'TOVS120   '
               CALL EXT_TOVS(NBTOVS120,INBTOVS120,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TOVS120))
               IF ( INBTOVS120.GT.0 ) INBOBS = INBOBS + INBTOVS120
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des ATOVS
!  --------------------

            IF ( LATOVS .AND. NBATOVS.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'ATOVS     '
               CALL EXT_ATOVS(NBATOVS,INBATOVS,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_ATOVS))
               IF ( INBATOVS.GT.0 ) INBOBS = INBOBS + INBATOVS
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees diffusiometriques
!  ----------------------------------------

            IF ( LERS1UWI .AND. NBERS1UWI.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'ERS1UWI   '
               CALL EXT_ERS1(NBERS1UWI,INBERS1UWI,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_ERS1UWI))
               IF ( INBERS1UWI.GT.0 ) INBOBS = INBOBS + INBERS1UWI
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees CYCLONE
!  ------------------------------

            IF ( LCYCLONE .AND. NBCYCLONE.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'CYCLONE   '
               CALL EXT_CYCLONE(NBCYCLONE,INBCYCLONE,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_CYCLONE))
               IF ( INBCYCLONE.GT.0 ) INBOBS = INBOBS + INBCYCLONE
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF


!  Extraction des donnees PAOB REUNION
!  -----------------------------------

            IF ( LPAOB_REU .AND. NBPAOBREU.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE='PAOBREU',FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM = 'CYCLONE   '
               CALL EXT_PAOBREU(NBPAOBREU,INBPAOBREU,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_PAOBREU))
!               IF ( INBPAOBREU.GT.0 ) INBOBS = INBOBS + INBPAOBREU
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF


!  Extraction des donnees TOVSMSU
!  ------------------------------

            IF ( LTOVSMSU .AND. NBTOVSMSU.GT.0 ) THEN
               IF ( NINIT.EQ.0 )
     &           OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                 POSITION='APPEND',STATUS='UNKNOWN')
               CLTYPM     = 'TOVSMSU   '
               CALL EXT_TOVSMSU(NBTOVSMSU,INBTMSU,CLTYPM,INBWAG,
     &           ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_TOVSMSU))
               IF ( INBTMSU.GT.0 ) INBOBS = INBOBS + INBTMSU
               IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
            ENDIF

!  Extraction des donnees SSMICE
!  -----------------------------

            IF ( LSSMICE.AND. NBSSMICE.GT.0 ) THEN
              CLTYPM     = 'SSMICE    '
              INBSSMICEE = MIN( NBSSMICE , 500000 )
              IF ( NINIT.EQ.0 )
     &          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
     &                POSITION='APPEND',STATUS='UNKNOWN')
              CALL EXT_SSMICE(INBSSMICEE,INBSSMICE,CLTYPM,INBWAG,
     &          ZLATN,ZLATS,ZLONO,ZLONE,INBSATEL,IPLEIN(N_SSMICE))
              IF ( INBSSMICE.GT.0 ) INBOBS = INBOBS + INBSSMICE
              IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
              DO J=1,JP_MAX_NB_SAT
                CLNBSAT(J) = '        '
                IF ( INBSATEL(J).NE.0 )
     &            WRITE (CLNBSAT(J),'(I8.0)') INBSATEL(J)
              ENDDO
              WRITE (NULOUT,104) CLNBSAT
 104          FORMAT(//,' extraction des donnees SSMICE ',/,1X,27('-'),
     &               //,'   numeros des satellites  :',9X,'F13/246   ',
     &               ' F14/247    F15/247    autres',//,'   nombres ',
     &               'de messages extraits  : ',4(A8,3X),/)
            ENDIF

!  Extraction des QUIKSCAT
!  -----------------------

!            IF ( LQUIKSCAT .AND. NBQUIKSCAT.GT.0 ) THEN
!              CLTYPM = 'QUIKSCAT  '
!              IF ( L_QUIKSCAT_OBSOUL ) THEN
!                IF ( NINIT.EQ.0 )
!     &            OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
!     &                  POSITION='APPEND',STATUS='UNKNOWN')
!                CALL OULAN_QUIKSCAT_TO_OBSOUL(NBQUIKSCAT,INBQUIKSCAT,
!     &            CLTYPM,INBWAG,IPLEIN(N_QUIKSCAT))
!                IF ( INBQUIKSCAT.GT.0 ) INBOBS = INBOBS + INBQUIKSCAT
!                IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
!              ELSE
!                IF ( NINIT.EQ.0 )
!     &            OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',
!     &                  POSITION='APPEND',STATUS='UNKNOWN')
!                CALL EXT_QUIKSCAT(NBQUIKSCAT,INBQUIKSCAT,CLTYPM,
!     &            INBWAG,ZLATN,ZLATS,ZLONO,ZLONE,IPLEIN(N_QUIKSCAT))
!                IF ( INBQUIKSCAT.GT.0 ) INBOBS = INBOBS + INBQUIKSCAT
!                IF ( NINIT.EQ.0 ) CLOSE (NULOBI)
!              ENDIF
!            ENDIF

      ENDDO BOUCLE_ZONE_GEO

      IF ( NINIT.EQ.0  ) CLOSE (NULOBI)
      IF ( L_GEOPOINTS ) CLOSE (NULGEO)

!-----------------------------------------------------------------------

!  Impressions
!  -----------

      IF ( LSYNOP      ) WRITE (CLNOEC( 1),'(I6)') INBSYNOP
      IF ( LSHIP       ) WRITE (CLNOEC( 2),'(I6)') INBSHIP
      IF ( LSYNOR      ) WRITE (CLNOEC( 3),'(I6)') INBSYNOR
      IF ( LRADOMEH    ) WRITE (CLNOEC( 4),'(I6)') INBRADOMEH
      IF ( LSYNOP.OR.LSHIP.OR.LSYNOR.OR.LRADOMEH )
     &   WRITE (CLNOEC( 5),'(I6)') INBSYNOP + INBSHIP + INBSYNOR +
     &                             INBRADOMEH
      IF ( LAIREP      ) WRITE (CLNOEC( 6),'(I6)') INBAIREP
      IF ( LAMDAR      ) WRITE (CLNOEC( 7),'(I6)') INBAMDAR
      IF ( LACAR       ) WRITE (CLNOEC( 8),'(I6)') INBACAR
      IF ( LAIREP.OR.LAMDAR.OR.LACAR )
     &   WRITE (CLNOEC( 9),'(I6)') INBAIREP + INBAMDAR + INBACAR
      IF ( LSATOB      ) WRITE (CLNOEC(10),'(I6)') INBSATOB
      IF ( LSATGEO     ) WRITE (CLNOEC(11),'(I6)') INBSATGEO
!      IF ( LGEOWIND    ) WRITE (CLNOEC(41),'(I6)') INBGEOWIND
      IF ( LSATOB.OR.LSATGEO )
     &   WRITE (CLNOEC(12),'(I6)') INBSATOB + INBSATGEO
      IF ( LBUOY       ) WRITE (CLNOEC(13),'(I6)') INBBUOY
      IF ( LBATHY      ) WRITE (CLNOEC(14),'(I6)') INBBATHY
      IF ( LTESAC      ) WRITE (CLNOEC(15),'(I6)') INBTESAC
      IF ( LBUOY.OR.LBATHY.OR.LTESAC )
     &   WRITE (CLNOEC(16),'(I6)') INBBUOY + INBBATHY + INBTESAC
      IF ( LTEMP       ) WRITE (CLNOEC(17),'(I6)') INBTEMP
      IF ( LTEMPSHIP   ) WRITE (CLNOEC(18),'(I6)') INBTEMPSHIP
      IF ( LTEMPMOBIL  ) WRITE (CLNOEC(19),'(I6)') INBTEMPMOBIL
      IF ( LTEMPDROP   ) WRITE (CLNOEC(20),'(I6)') INBTEMPDROP
      IF ( LTEMP.OR.LTEMPSHIP.OR.LTEMPMOBIL.OR.LTEMPDROP )
     &   WRITE (CLNOEC(21),'(I6)') INBTEMP + INBTEMPSHIP +
     &                             INBTEMPMOBIL + INBTEMPDROP
      IF ( LPILOT      ) WRITE (CLNOEC(22),'(I6)') INBPILOT
      IF ( LPILOTSHIP  ) WRITE (CLNOEC(23),'(I6)') INBPILOTSHIP
      IF ( LPILOTMOBIL ) WRITE (CLNOEC(24),'(I6)') INBPILOTMOBIL
      IF ( LEUROPROFIL ) WRITE (CLNOEC(25),'(I6)') INBEUROPROFIL
      IF ( LPROFILER   ) WRITE (CLNOEC(26),'(I6)') INBPROFILER
      IF ( LPILOT .OR. LPILOTSHIP .OR. LPILOTMOBIL .OR. 
     &     LEUROPROFIL .OR. LPROFILER )
     &   WRITE (CLNOEC(27),'(I6)') INBPILOT+INBPILOTSHIP+INBPILOTMOBIL+
     &                             INBEUROPROFIL+INBPROFILER
      IF ( LSATEM      ) WRITE (CLNOEC(28),'(I6)') INBSATEM
      IF ( LTOVS120    ) WRITE (CLNOEC(29),'(I6)') INBTOVS120
      IF ( LATOVS      ) WRITE (CLNOEC(30),'(I6)') INBATOVS
      IF ( LSSMI       ) WRITE (CLNOEC(31),'(I6)') INBSSMI
      IF ( LSSMICE     ) WRITE (CLNOEC(32),'(I6)') INBSSMICE
      IF ( LTOVSHIRS   ) WRITE (CLNOEC(33),'(I6)') INBTHIRS
      IF ( LTOVSMSU    ) WRITE (CLNOEC(34),'(I6)') INBTMSU
      IF ( LTOVSAMSUA  ) WRITE (CLNOEC(35),'(I6)') INBTAMSUA
      IF ( LTOVSAMSUB  ) WRITE (CLNOEC(36),'(I6)') INBTAMSUB
      IF ( LSATEM.OR.LTOVS120.OR.LATOVS.OR.LSSMI.OR.LSSMICE.OR.
     &     LTOVSHIRS.OR.LTOVSMSU.OR.LTOVSAMSUA.OR.LTOVSAMSUB ) 
     &   WRITE (CLNOEC(37),'(I6)') INBSATEM + INBTOVS120 + INBATOVS  +
     &                             INBSSMI  + INBSSMICE  + INBTHIRS  +
     &                             INBTMSU  + INBTAMSUA  + INBTAMSUB
      IF ( LCYCLONE ) THEN
        WRITE (CLNOEC(38),'(I6)') INBCYCLONE
        CLNOEC(39) = CLNOEC(38)
      ENDIF
!      IF ( LERS1UWI ) WRITE (CLNOEC(40),'(I6)') INBERS1UWI
!      IF ( LQUIKSCAT ) WRITE (CLNOEC(42),'(I6)') INBQUIKSCAT
      IF ( LERS1UWI ) 
     &  WRITE (CLNOEC(43),'(I6)') INBERS1UWI
      IF ( LAIRSBT ) WRITE (CLNOEC(44),'(I6)') INBAIRSBT
      IF ( LGPSSOL ) WRITE (CLNOEC(45),'(I6)') INBGPSSOL
      IF ( LPAOB_REU ) WRITE (CLNOEC(46),'(I6)') INBPAOBREU
      IF ( INBOBS.GE.0 ) WRITE (CLNOEC(47),'(I6)') INBOBS

      WRITE (NULOUT,302)
      DO J=1,JP_MAX_MES
        IF ( IPLEIN(J).NE.0 ) WRITE (NULOUT,303) IPLEIN(J),CDTPMBDM(J)
      ENDDO
      WRITE (NULOUT,302)
      WRITE (NULOUT,301) (CLNOEC(J),J=1,11),
     &                   (CLNOEC(J),J=12,39),(CLNOEC(J),J=43,47)
      WRITE (NULOUT,305) INBPAOBREU
!-----------------------------------------------------------------------
!  Impression du fichier refdata
!
      IF ( (INBSYNOP + INBSHIP + INBSYNOR + INBRADOMEH + INBGPSSOL)
     &    .GT. 0 ) CLTYPGEN(1)=' SYNOP'
      IF ( (INBAIREP + INBAMDAR + INBACAR) .GT. 0 ) CLTYPGEN(2)=' AIREP'
      IF ( (INBSATOB + INBSATGEO) .GT. 0 )
     &   CLTYPGEN(3)=' SATOB'
      IF ( (INBBUOY + INBBATHY + INBTESAC) .GT. 0 ) CLTYPGEN(4)=' BRIBU'
      IF ( (INBTEMP + INBTEMPSHIP + INBTEMPMOBIL + INBTEMPDROP) .GT. 0 )
     &   CLTYPGEN(5)=' TEMP'
      IF ( (INBPILOT + INBPILOTSHIP + INBPILOTMOBIL + INBEUROPROFIL +
     &   INBPROFILER) .GT. 0 )
     &   CLTYPGEN(6)=' PILOT'
      IF ( INBTAMSUA .GT. 0 ) CLTYPGEN(7)=' AMSUA'
      IF ( INBTAMSUB .GT. 0 ) CLTYPGEN(8)=' AMSUB'
      IF ( INBTHIRS .GT. 0 ) CLTYPGEN(9)=' HIRS'

      IF ( INBAIRSBT .GT. 0 .AND. L_AIRSBT_AIRS ) CLTYPGEN(10)=' AIRS'
      IF ( INBAIRSBT .GT. 0 .AND. L_AIRSBT_AMSUA) CLTYPGEN(7)=' AMSUA'

      IF ( (INBSSMI + INBSSMICE) .GT. 0 ) CLTYPGEN(11)=' SSMI'
      IF ( (INBERS1UWI) .GT. 0 ) CLTYPGEN(12)=' QSCAT'
      IF ( INBCYCLONE .GT. 0 ) CLTYPGEN(13)=' CYCLO'

      INB0 = MIN ( 1 , 
     &       INBSYNOP + INBSHIP + INBSYNOR + INBRADOMEH + INBAIREP + 
     &       INBAMDAR + INBACAR + INBSATOB + INBSATGEO  + INBBUOY  +
     &       INBBATHY + INBTESAC+ INBTEMP + INBTEMPSHIP + INBTEMPMOBIL + 
     &       INBTEMPDROP + INBPILOT + INBPILOTSHIP + INBPILOTMOBIL +
     &       INBEUROPROFIL + INBPROFILER + INBERS1UWI + INBCYCLONE ) 
      INB1 = MIN ( 1 , INBSSMICE )
      INB2 = MIN ( 1 , 0 )
      INB3 = MIN ( 1 , INBTAMSUA + INBTAMSUB + INBTHIRS + INBAIRSBT +
     &             INBSSMI )
      IF ( ( INB0 + INB1 + INB2 + INB3 ) .GT. 1 ) THEN
        IB200=-999 
      ELSE
        IF ( INB0 .GT. 0 ) IB200 = 0 
        IF ( INB1 .GT. 0 ) IB200 = -4
        IF ( INB2 .GT. 0 ) IB200 = -8
        IF ( INB3 .GT. 0 ) IB200 = -12
      ENDIF

      IF ( NINIT .EQ. 0 ) THEN
        OPEN (NULRFD,FILE='REFDATA',FORM='FORMATTED',POSITION='APPEND',
     &        STATUS='UNKNOWN')
        WRITE(NULRFD,319) CNAMEOBSOUL,'OBSOUL  ',CNAMEOBSOUL,NDATE,
     &                    NRESO,INBOBS,INBWAG,'5',IB200,CDATDEB(2),
     &                    CDATFIN(2),(CLTYPGEN(IG),IG=1,13)
        CLOSE(NULRFD)

! ecriture du batormap de reference ------------------------------------
        OPEN (NULMAPR,FILE='BATORMAP_REF',FORM='FORMATTED',
     &        POSITION='APPEND',STATUS='UNKNOWN')
        WRITE(NULMAPR,'(A8," ",A8," OBSOUL    ",A16)')CNAMEBASE,
     &                          CNAMEOBSOUL,CNAMEOBSOUL
        CLOSE(NULMAPR)

        IF ( INBOBS .EQ. 0 ) THEN
          OPEN (NULOBI,FILE=FULL_NAME,FORM='FORMATTED',STATUS='UNKNOWN')
          CLOSE (NULOBI,STATUS='DELETE')
      	ELSE
! ecriture du batormap reel ------------------------------------
          OPEN (NULMAP,FILE=FULL_BMAP,FORM='FORMATTED',
     &          POSITION='APPEND',STATUS='UNKNOWN')
          WRITE(NULMAP,'(A8," ",A8," OBSOUL    ",A16)')CNAMEBASE,
     &                            CNAMEOBSOUL,CNAMEOBSOUL
          CLOSE(NULMAP)
        ENDIF
        IF ( INBPAOBREU .EQ. 0 ) THEN
          OPEN (NULOBI,FILE='PAOBREU',FORM='FORMATTED',STATUS='UNKNOWN')
          CLOSE (NULOBI,STATUS='DELETE')
!        ELSE
! ecriture du batormap reel ------------------------------------
!        OPEN (NULMAP,FILE='BATORMAP',FORM='FORMATTED',
!     &        POSITION='APPEND',STATUS='UNKNOWN')
!        WRITE(NULMAP,'(A8," ",A8," OBSOUL    ",A16)')CNAMEBASE,
!     &                          CNAMEOBSOUL,CNAMEOBSOUL
!        CLOSE(NULMAP)
	
        ENDIF
      ENDIF

!-----------------------------------------------------------------------

!  Formats
!  -------

 300  CONTINUE

 301  FORMAT(/,5X,'Nombres de messages extraits',48X,'total cat.',//,
     &  ' SYNOP      : ',A6,'  SHIP',7X,': ',A6,'  SYNOR      : ',A6,
     &  '  RADOMEH    : ',A6,3X,A6,/,' AIREP      : ',A6,'  AMDAR   ',
     &  '   : ',A6,'  ACAR       : ',A6,24X,A6,/,' SATOB      : ',A6,
     &  '  SATGEO     : ',A6,
     &  24X,A6,/,' BUOY',7X,': ',A6,'  BATHY      : ',A6,'  TESAC   ',
     &  '   : ',A6,24X,A6,/,' TEMP       : ',A6,'  TEMPSHIP   : ',A6,
     &  '  TEMPMOBIL  : ',A6,'  TEMPDROP   : ',A6,3X,A6,/,' PILOT    ',
     &  '  : ',A6,'  PILOTSHIP  : ',A6,'  PILOTMOBIL : ',A6,/,' EUROP',
     &  'ROFIL : ',A6,'  PROFILER   : ',A6,45X,A6,/,' SATEM      : ',
     &  A6,'  TOVS120    : ',A6,'  ATOVS      : ',A6,/,' SSMI',7X,': ',
     &  A6,'  SSMICE     : ',A6,/,' TOVSHIRS   : ',A6,'  TOVSMSU    : '
     &  ,A6,'  TOVSAMSUA  : ',A6,'  TOVSAMSUB  : ',A6,3X,A6,/,
     &  ' CYCLONE    : ',A6,67X,A6,/,' ERS1UWI    : ',A6,
     &  '  AIRSBT     : ',A6,/,' GPSSOL     : ',A6,
     &  '  PAOB_REU   : ',A6,//,
     &  ' nombre total d''observations transferees dans OBSOUL: ',A6)
 302  FORMAT(/)
 303  FORMAT(' ATTENTION : le nombre de messages demandes (',I6,') ',
     &       'est atteint pour le type ',A10)
 305  FORMAT(' nombre d''observations transferees dans PAOBREU: ',
     & '     ',I6,/)
 319  FORMAT(A8,1X,A8,1X,A16,1X,I8,1X,I2,1X,I8,1X,I9,1X,A,1X,I4,1X,
     &       2(A14,1X),13(A6))

!-----------------------------------------------------------------------

      RETURN
      END
